@@ -384,7 +384,7 @@ def checklocalfeature(localcheck, featurelist, sequence, refdir, circular, lengt
 
         # remove if single feature shorter 56
         if len(localfeats) == 1 and localfeats[0].length(circular, length) <= 55:
-            logging.error("checklocalfeature: remove %s %d %d (single & <55)" % (
+            logging.debug("checklocalfeature: remove %s %d %d (single & <55)" % (
                 localfeats[0].name, localfeats[0].start, localfeats[0].stop))
             featurelist.remove(localfeats[0])
             continue
@@ -465,7 +465,7 @@ def checklocalfeature(localcheck, featurelist, sequence, refdir, circular, lengt
 
         struct = cmrealign(sseq, featurelist[i].name, refdir)
 
-        newfeat = feature.mitfifeature(name=featurelist[i].name, type="rRNA", start=start, stop=stop,
+        newfeat = feature.mitfifeature(name=featurelist[i].name, tpe="rRNA", start=start, stop=stop,
                                        strand=featurelist[i].strand,
                                        score=(
                                            featurelist[i].score + featurelist[ii].score) / 2.0,
@@ -625,4 +625,4 @@ def _copy_part(hits, fragovl, fragfac):
             if len(predictions[name]) > 1:
                 k += 1
 
-    return cpyprt
\ No newline at end of file
+    return cpyprt
