@@ -103,7 +103,7 @@ class mitofromfile( gb ):
 
 #             print data
             if data["type"] == "tRNA" or data["type"] == "rRNA":
-                nf = mitfifeature( name = data["name"], type = data["type"], start = data["start"], \
+                nf = mitfifeature( name = data["name"], tpe = data["type"], start = data["start"], \
                                  stop = data["stop"], strand = data["strand"], score = data["score"], sequence = None, \
                                  struct = data["struct"], anticodonpos = data["anticodonpos"], anticodon = data["anticodon"], \
                                  qstart = None, qstop = None,
