@@ -424,6 +424,9 @@ def prot_feat(seq, code, startcod, stopcod, len_pval, trnas, idx, values, refdir
 
         for gene in mito.metazoa_prot:
             dbFile = refdir + '/featureProtHMM/' + gene + '.db'
+            if not os.path.exists(dbFile):
+                logging.warning("skipping nonexistent hmmdb for %s" % gene)
+                continue
             hmmscan_call(protFile, gene, dbFile, protFile)
 
     featlist = []
@@ -431,8 +434,8 @@ def prot_feat(seq, code, startcod, stopcod, len_pval, trnas, idx, values, refdir
     for gene in mito.metazoa_prot:
         outDir = tmpDir + filename + "-?.fas-" + gene + ".tbl"
         outList = glob.glob(outDir)
-        print(outDir, outList)
-
+        if len(outList) == 0:
+            continue
         merged = merge_frames(gene, outList, tmpDir + filename)
         featlist += get_best_hits(merged, gene,
                                   seqLen, evalTh, finovl, circular)
