@@ -18,19 +18,30 @@ from Bio import SeqIO
 from Bio.Alphabet.IUPAC import ambiguous_dna
 from Bio.SeqRecord import SeqRecord
 
-from mitos import blast
-from mitos import bedfile
-from mitos import gfffile
-from mitos import feature
-from mitos.mergefeature import featureappend, checklocalfeature, _copy_part
-from mitos import mitfi
-from mitos import mito
+from mitos import (
+    __version__,
+    bedfile,
+    blast,
+    gfffile,
+    feature,
+    mitfi,
+    mito,
+    protfeat,
+    sequin,
+    trna
+)
+from mitos.mergefeature import (
+    featureappend,
+    checklocalfeature,
+    _copy_part
+)
 from mitos.mitofile import mitowriter
-from mitos import protfeat
 from mitos.rna.vienna import RNAplot
-from mitos.sequence import fastawriter, sequence_info_fromfile, sequence_info_fromfilehandle
-from mitos import trna
-from mitos import sequin
+from mitos.sequence import (
+    fastawriter,
+    sequence_info_fromfile,
+    sequence_info_fromfilehandle
+)
 
 
 def mitos(fastafile, code, ncbicode, best, order, alarab=False,
@@ -850,7 +861,7 @@ if __name__ == '__main__':
 
     import argparse
     usage = "usage: %prog [options]"
-    parser = argparse.ArgumentParser(usage)
+    parser = argparse.ArgumentParser(prog="runmitos.py", usage=usage)
 
     group = parser.add_argument_group("mandatory options")
     ingroup = parser.add_mutually_exclusive_group(required=False)
@@ -932,7 +943,7 @@ if __name__ == '__main__':
         "--debug", action="store_true", default=False, help="print debug output")
     group.add_argument("--json", default=None,
                        help="a JSON file with parameters. then outdir is the only other argument needed.")
-
+    parser.add_argument('--version', action='version', version='%(prog)s {version}'.format(version=__version__))
     args = parser.parse_args()
 
     if args.json is not None:
@@ -1032,8 +1043,8 @@ if __name__ == '__main__':
         sequin.sequinwriter(featurelist, acc, outfile="%s/result.seq" % odir)
         gfffile.gffwriter(featurelist, acc, outfile = "%s/result.gff" % odir, mode = "w")
         feature.genorderwriter( featurelist, acc, "%s/result.geneorder" % odir)
-        fastawriter( featurelist, sequences[0]["sequence"], None, acc, "fas", outfile = "%s/result.fas" % odir)
-        fastawriter( featurelist, sequences[0]["sequence"], args.code, acc, "faa", outfile = "%s/result.faa" % odir)
+        fastawriter( featurelist, sequences[i]["sequence"], None, acc, "fas", outfile = "%s/result.fas" % odir)
+        fastawriter( featurelist, sequences[i]["sequence"], args.code, acc, "faa", outfile = "%s/result.faa" % odir)
 
         # parse fasta header
         sequence = sequences[i]["sequence"]
